@@ -36,10 +36,10 @@ typedef struct sstp_peer
     char name[255];
 
     /*! The address information of our peer */
-    struct sockaddr addr;
+    struct sockaddr_storage addr;
 
     /*! The address length */
-    int alen;
+    socklen_t alen;
     
     /*! The peer's ssl session (for re-connect) */
     void *ssl_session;
@@ -88,6 +88,14 @@ typedef struct
     /*! The event base */
     event_base_st *ev_base;
 
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+    /*! The legacy provider */
+    OSSL_PROVIDER *legacy;
+
+    /*! The default provider */
+    OSSL_PROVIDER *provider;
+#endif
+
 } sstp_client_st;
 
 
